@@ -661,6 +661,7 @@ int PacketHandler::forwardPacket(const string &msgPrefix, const DNSPacket& p, co
 
 }
 
+// NOLINTNEXTLINE(readability-function-cognitive-complexity)
 int PacketHandler::processUpdate(DNSPacket& p) {
   if (! ::arg().mustDo("dnsupdate"))
     return RCode::Refused;
@@ -806,8 +807,10 @@ int PacketHandler::processUpdate(DNSPacket& p) {
     const DNSRecord* rr = &i.first;
     if (rr->d_place == DNSResourceRecord::ANSWER) {
       // Last line of 3.2.3
-      if (rr->d_class != QClass::IN && rr->d_class != QClass::NONE && rr->d_class != QClass::ANY)
+      if (rr->d_class != QClass::IN && rr->d_class != QClass::NONE && rr->d_class != QClass::ANY) {
+        di.backend->abortTransaction();
         return RCode::FormErr;
+      }
 
       if (rr->d_class == QClass::IN) {
         rrSetKey_t key = {rr->d_name, QType(rr->d_type)};
